# disperseNN2

[![Documentation Status](https://readthedocs.org/projects/dispersenn2/badge/?version=latest)](https://dispersenn2.readthedocs.io/en/latest/?badge=latest)

`disperseNN2` is a machine learning framework for predicting &#963;, the expected per generation displacement distance between offspring and their parent(s), from genetic variation data.
`disperseNN2` replaces our previous method, `disperseNN`, by introducing
a novel architecture. For details see our preprint (LINK).

For installation and usage instructions, see the [docs page](https://dispersenn2.readthedocs.io/en/latest/).
